#
# spec file for package python-geopandas
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-geopandas%{psuffix}
Version:        0.14.4
Release:        1.1
Summary:        Geographic pandas extensions
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://geopandas.org
# SourceRepository: https://github.com/geopandas/geopandas
Source:         https://files.pythonhosted.org/packages/source/g/geopandas/geopandas-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       proj
Requires:       python-Fiona >= 1.8.21
Requires:       python-numpy >= 1.22
Requires:       python-packaging
Requires:       python-pandas >= 1.4.0
Requires:       python-pyproj >= 3.3.0
Requires:       python-shapely >= 1.8.0
Recommends:     python-geopy
Recommends:     python-matplotlib
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Rtree}
BuildRequires:  %{python_module folium if %python-base >= 3.10}
BuildRequires:  %{python_module fsspec}
BuildRequires:  %{python_module geopandas = %{version}}
BuildRequires:  %{python_module geopy}
BuildRequires:  %{python_module matplotlib >= 3.5.0}
BuildRequires:  %{python_module numpy >= 1.22}
BuildRequires:  %{python_module psycopg2}
BuildRequires:  %{python_module pyarrow}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module sqlalchemy}
# mapclassify not yet available
#BuildRequires: %%{python_module mapclassify}
%endif
%python_subpackages

%description
Geopandas combines the capabilities of pandas and shapely, providing geospatial
operations in pandas and a high-level interface to multiple geometries to shapely.
GeoPandas enables you to easily do operations in python that would otherwise
require a spatial database such as PostGIS.

%prep
%autosetup -p1 -n geopandas-%{version}

%build
%if ! %{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
# online resource
donttest="test_read_file_url"
# test files missing in sdist
donttest="$donttest or test_overlay"
donttest="$donttest or (test_arrow and (test_read_versioned_file or test_read_gdal_file))"
# wrong shapely type
donttest="$donttest or (test_geom_methods and test_sample_points_array)"
donttest="$donttest or (test_random and test_uniform and geom)"
if [ $(getconf LONG_BIT) -eq 32 ]; then
  donttest="$donttest or test_explode or test_get_coordinates_parts"
fi
%pytest -rsfE -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE.txt
%{python_sitelib}/geopandas
%{python_sitelib}/geopandas-%{version}.dist-info
%endif

%changelog
* Sun May  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.14.4
  * Several fixes for compatibility with the upcoming pandas 3.0,
    numpy 2.0 and fiona 1.10 releases.
* Thu Mar 21 2024 Ben Greiner <code@bnavigator.de>
- Don't test folium on python39: no longer available
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.14.3
  * Several fixes for compatibility with the latest pandas 2.2
    release.
  * Fix bug in pandas.concat CRS consistency checking where CRS
    differing by WKT whitespace only were treated as incompatible
    (#3023).
- Version 0.14.2 (Jan 4, 2024)
  * Fix regression in overlay where using buffer(0) instead of
    make_valid internally produced invalid results (#3074).
  * Fix explore() method when the active geometry contains missing
    and empty geometries (#3094).
* Fri Nov 24 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14.1
  * The Parquet and Feather IO functions now support the latest
    1.0.0 version of the GeoParquet specification (geoparquet.org)
    (#2663).
  * Fix read_parquet and read_feather for CVE-2023-47248 (#3070).
- Remove deprecated pygeos from testing: It is included in Shapely
  now
* Wed Oct 25 2023 Ben Greiner <code@bnavigator.de>
- Skip a test still failing with pandas 2.1.1
  * See gh#geopandas/geopandas#2948, gh#geopandas/geopandas#2994,
    gh#geopandas/geopandas#3038
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14.0
  * GeoPandas will use Shapely 2.0 by default instead of PyGEOS
    when both Shapely >= 2.0 and PyGEOS are installed. PyGEOS will
    continue to be used by default when PyGEOS is installed
    alongside Shapely < 2.0. Support for PyGEOS and Shapely < 2.0
    will be removed in GeoPandas 1.0. (#2999)
  [#]# API changes:
  * seed keyword in sample_points is deprecated. Use rng instead.
    (#2913).
  [#]# New methods:
  * Added concave_hull method from shapely to
    GeoSeries/GeoDataframe (#2903).
  * Added delaunay_triangles method from shapely to
    GeoSeries/GeoDataframe (#2907).
  * Added extract_unique_points method from shapely to
    GeoSeries/GeoDataframe (#2915).
  * Added frechet_distance() method from shapely to
    GeoSeries/GeoDataframe (#2929).
  * Added hausdorff_distance method from shapely to
    GeoSeries/GeoDataframe (#2909).
  * Added minimum_rotated_rectangle method from shapely to
    GeoSeries/GeoDataframe (#2541).
  * Added offset_curve method from shapely to
    GeoSeries/GeoDataframe (#2902).
  * Added remove_repeated_points method from shapely to
    GeoSeries/GeoDataframe (#2940).
  * Added reverse method from shapely to GeoSeries/GeoDataframe
    (#2988).
  * Added segmentize method from shapely to GeoSeries/GeoDataFrame
    (#2910).
  * Added shortest_line method from shapely to
    GeoSeries/GeoDataframe (#2960).
  [#]# New features and improvements:
  * Added exclusive parameter to sjoin_nearest method for Shapely
    >= 2.0 (#2877)
  * The to_file() method will now automatically detect the
    FlatGeoBuf driver
  * for files with the .fgb extension (#2958)
  [#]# Bug fixes:
  * Fix ambiguous error when GeoDataFrame is initialized with a
    column called "crs" (#2944)
  * Fix a color assignment in explore when using UserDefined bins
    (#2923)
  * Fix bug in apply with axis=1 where the given user defined
    function returns nested
  * data in the geometry column (#2959)
  * Properly infer schema for np.int32 and pd.Int32Dtype columns
    (#2950)
  * assert_geodataframe_equal now handles GeoDataFrames with no
    active geometry (#2498)
  [#]# Notes on (optional) dependencies:
  * GeoPandas 0.14 drops support for Python 3.8 and pandas 1.3 and
    below (the minimum
  * supported pandas version is now 1.4). Further, the minimum
    required versions for the
  * listed dependencies have now changed to shapely 1.8.0, fiona
    1.8.21, pyproj 3.3.0 and
  * matplotlib 3.5.0 (#3001)
  [#]# Deprecations and compatibility notes:
  * geom_almost_equals() methods have been deprecated and
  * geom_equals_exact() should be used instead (#2604).
* Thu Jun 22 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.13.2
  * Fix a regression in reading from local file URIs (file://..)
    using geopandas.read_file (#2948).
  * Fix a regression in reading from URLs using geopandas.read_file
    (#2908). This restores the behaviour to download all data
    up-front before passing it to the underlying engine (fiona or
    pyogrio), except if the server supports partial requests (to
    support reading a subset of a large file).
- Relese 0.13
  [#]# New methods:
  * Added sample_points method to sample random points from Polygon
    or LineString geometries (#2860).
  * New hilbert_distance() method that calculates the distance
    along a Hilbert curve for each geometry in a
    GeoSeries/GeoDataFrame (#2297).
  * Support for sorting geometries (for example, using
    sort_values()) based on the distance along the Hilbert curve
    (#2070).
  * Added get_coordinates() method from shapely to
    GeoSeries/GeoDataframe (#2624).
  * Added minimum_bounding_circle() method from shapely to
    GeoSeries/GeoDataframe (#2621).
  * Added minimum_bounding_radius() as GeoSeries method (#2827).
  [#]# Other new features and improvements:
  * The Parquet and Feather IO functions now support the latest
    1.0.0-beta.1 version of the GeoParquet specification
    (<geoparquet.org>) (#2663).
  * Added support to fill missing values in GeoSeries.fillna via
    another GeoSeries (#2535).
  * Support specifying min_zoom and max_zoom inside the map_kwds
    argument for .explore() (#2599).
  * Added support for append (mode="a" or append=True) in to_file()
    using engine="pyogrio" (#2788).
  * Added a to_wgs84 keyword to to_json allowing automatic
    re-projecting to follow the 2016 GeoJSON specification (#416).
  * to_json output now includes a "crs" field if the CRS is not the
    default WGS84 (#1774).
  * Improve error messages when accessing the geometry attribute of
    GeoDataFrame without an active geometry column related to the
    default name "geometry" being provided in the constructor
    (#2577)
  [#]# Deprecations and compatibility notes:
  * Added warning that unary_union will return 'GEOMETRYCOLLECTION
    EMPTY' instead of None for all-None GeoSeries. (#2618)
  * The query_bulk() method of the spatial index .sindex property
    is deprecated in favor of query() (#2823).
  [#]# Bug fixes:
  * Ensure that GeoDataFrame created from DataFrame is a copy, not
    a view (#2667)
  * Fix mismatch between geometries and colors in plot() if an
    empty or missing geometry is present (#2224)
  * Escape special characters to avoid TemplateSyntaxError in
    explore() (#2657)
  * Fix to_parquet/to_feather to not write an invalid bbox (with
    NaNs) in the metadata in case of an empty GeoDataFrame (#2653)
  * Fix to_parquet/to_feather to use correct WKB flavor for 3D
    geometries (#2654)
  * Fix read_file to avoid reading all file bytes prior to calling
    Fiona or Pyogrio if provided a URL as input (#2796)
  * Fix copy() downcasting GeoDataFrames without an active geometry
    column to a DataFrame (#2775)
  * Fix geometry column name propagation when GeoDataFrame columns
    are a multiindex (#2088)
  * Fix iterfeatures() method of GeoDataFrame to correctly handle
    non-scalar values when na='drop' is specified (#2811)
  * Fix issue with passing custom legend labels to plot (#2886)
  [#]# Notes on (optional) dependencies:
  * GeoPandas 0.13 drops support pandas 1.0.5 (the minimum
    supported pandas version is now 1.1). Further, the minimum
    required versions for the listed dependencies have now changed
    to shapely 1.7.1, fiona 1.8.19, pyproj 3.0.1 and matplotlib
    3.3.4 (#2655)
- Release 0.12.2
  * Correctly handle geometries with Z dimension in to_crs() when
    using PyGEOS or Shapely >= 2.0 (previously the z coordinates
    were lost) (#1345).
  * Assign Crimea to Ukraine in the naturalearth_lowres built-in
    dataset (#2670)
- Release 0.12
  * The highlight of this release is the support for Shapely 2.0.
    This makes it possible to test Shapely 2.0 (currently 2.0b1)
    alongside GeoPandas.
  * Note that if you also have PyGEOS installed, you need to set an
    environment variable (USE_PYGEOS=0) before importing geopandas
    to actually test Shapely 2.0 features instead of PyGEOS. See
    https://geopandas.org/en/latest/getting_started/install.html#using-the-optional-pygeos-dependency
    for more details.
  [#]# New features and improvements:
  * Added normalize() method from shapely to GeoSeries/GeoDataframe
    (#2537).
  * Added make_valid() method from shapely to
    GeoSeries/GeoDataframe (#2539).
  * Added where filter to read_file (#2552).
  * Updated the distributed natural earth datasets
    (naturalearth_lowres and naturalearth_cities) to version 5.1
    (#2555).
  [#]# Deprecations and compatibility notes:
  * Accessing the crs of a GeoDataFrame without active geometry
    column was deprecated and this now raises an AttributeError
    (#2578).
  * Resolved colormap-related warning in .explore() for recent
    Matplotlib versions (#2596).
  [#]# Bug fixes:
  * Fix cryptic error message in geopandas.clip() when clipping
    with an empty geometry (#2589).
  * Accessing gdf.geometry where the active geometry column is
    missing, and a column named "geometry" is present will now
    raise an AttributeError, rather than returning gdf["geometry"]
    (#2575).
  * Combining GeoSeries/GeoDataFrames with pandas.concat will no
    longer silently override CRS information if not all inputs have
    the same CRS (#2056).
* Sat Feb 25 2023 Matej Cepl <mcepl@suse.com>
- Split package into multibuild to avoid a build cycle
  (bsc#1207791).
* Fri Sep 16 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v0.11.1
* Fri Aug 21 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.8.1
* Tue Dec 10 2019 Todd R <toddrme2178@gmail.com>
- initial version for v0.6.2
